@@ -143,11 +143,6 @@ namespace nux
           View *ic = static_cast<View *>(*it);
           ic->ProcessDraw(graphics_engine, true);
         }
-        else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
-        {
-          InputArea *base_area = static_cast<InputArea *>(*it);
-          base_area->OnDraw(graphics_engine, true);
-        }
         else if ((*it)->Type().IsObjectType(HLayout::StaticObjectType))
         {
           HLayout *layout = static_cast<HLayout *>(*it);
@@ -166,11 +161,6 @@ namespace nux
           View *ic = static_cast<View *>(*it);
           ic->ProcessDraw(graphics_engine, false);
         }
-        else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
-        {
-          InputArea *base_area = static_cast<InputArea *>(*it);
-          base_area->OnDraw(graphics_engine, false);
-        }
         else if ((*it)->Type().IsObjectType(HLayout::StaticObjectType))
         {
           HLayout *layout = static_cast<HLayout *>(*it);
@@ -359,11 +349,6 @@ namespace nux
         // ComputeElementLayout to force the computing of this element layout.
         GetWindowThread()->ComputeElementLayout(ic);
       }
-      else if (m_InterfaceObject[i]->Type().IsObjectType(InputArea::StaticObjectType))
-      {
-        InputArea *base_area = static_cast<InputArea *>(m_InterfaceObject[i]);
-        base_area->SetGeometry(Geometry(x, accheight, w, splitter_geo.y - accheight));
-      }
       else if (m_InterfaceObject[i]->Type().IsDerivedFromType(Layout::StaticObjectType))
       {
         Layout *layout = static_cast<Layout *>(m_InterfaceObject[i]);
@@ -566,11 +551,6 @@ namespace nux
         View *ic = static_cast<View *>(*it);
         ic->DoneRedraw();
       }
-
-      else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
-      {
-        //InputArea* base_area = NUX_STATIC_CAST(InputArea*, (*it));
-      }
     }
   }
 
