@@ -32,6 +32,10 @@
 #include "NuxGraphics/GraphicsEngine.h"
 #include "WindowCompositor.h"
 
+#ifdef NUX_GESTURES_SUPPORT
+#include "GesturesSubscription.h"
+#endif
+
 namespace nux
 {
 namespace {
@@ -62,12 +66,16 @@ logging::Logger logger("nux.inputarea");
 
   InputArea::~InputArea()
   {
+    while (GetWindowCompositor().GrabPointerRemove(this));
+    while (GetWindowCompositor().GrabKeyboardRemove(this));
   }
 
-  
   void InputArea::OnDraw(GraphicsEngine &graphics_engine, bool force_draw)
   {
-    graphics_engine.QRP_Color(GetBaseX(), GetBaseY(), GetBaseWidth(), GetBaseHeight(), area_color_);
+    // Draw Nothing!
+
+    // For debug Only:
+    // graphics_engine.QRP_Color(GetBaseX(), GetBaseY(), GetBaseWidth(), GetBaseHeight(), area_color_);
   }
 
   void InputArea::SetBaseString(const char *Caption)
@@ -411,5 +419,76 @@ logging::Logger logger("nux.inputarea");
 
     return true;
   }  
-}
 
+#ifdef NUX_GESTURES_SUPPORT
+  void InputArea::CreateGesturesSubscription(int gesture_classes,
+                                             unsigned int num_touches)
+  {
+    GesturesSubscription *subscription = new GesturesSubscription;
+    subscription->SetGestureClasses(gesture_classes);
+    subscription->SetNumTouches(num_touches);
+    subscription->Activate();
+
+    gestures_subscriptions_.push_back(ShGesturesSubscription(subscription));
+  }
+
+  void InputArea::AddGesturesSubscription(
+      std::shared_ptr<nux::GesturesSubscription> &subscription)
+  {
+    for (auto sub : gestures_subscriptions_)
+    {
+      if (sub.get() == subscription.get())
+        return;
+    }
+
+    gestures_subscriptions_.push_back(subscription);
+  }
+
+  void InputArea::RemoveGesturesSubscription(
+      std::shared_ptr<nux::GesturesSubscription> &subscription)
+  {
+    std::list<std::shared_ptr<nux::GesturesSubscription> >::iterator it;
+    for (it = gestures_subscriptions_.begin();
+        it != gestures_subscriptions_.end(); ++it)
+    {
+      if (it->get() == subscription.get())
+      {
+        gestures_subscriptions_.erase(it);
+        return;
+      }
+      ++it;
+    }
+  }
+
+  const std::list<ShGesturesSubscription>&
+  InputArea::GetGesturesSubscriptions() const
+  {
+    return gestures_subscriptions_;
+  }
+
+  bool InputArea::HasSubscriptionForGesture(const nux::GestureEvent &event) const
+  {
+    for (const auto subscription : gestures_subscriptions_)
+    {
+      if (subscription->MatchesGesture(event))
+        return true;
+    }
+
+    return false;
+  }
+
+  Area* InputArea::GetInputAreaHitByGesture(const nux::GestureEvent &event)
+  {
+    if (!IsVisible())
+      return nullptr;
+
+    if (!HasSubscriptionForGesture(event))
+      return nullptr;
+
+    if (!IsGestureInsideArea(event))
+      return nullptr;
+
+    return this;
+  }
+#endif // NUX_GESTURES_SUPPORT
+}
