@@ -45,7 +45,7 @@ namespace nux
     _index = 0;
     _tab_name = TabName;
     _tab_content_layout = TabLayout;
-    _tab_area = new InputArea(NUX_TRACKER_LOCATION);
+    _tab_area = new BasicView(NUX_TRACKER_LOCATION);
 
     _tab_content_layout->Reference();
     _tab_area->Reference();
@@ -100,8 +100,8 @@ namespace nux
     //_tabview_heads_layout->SetParentObject(this);
     _tabview_scroll_button_layout  = new HLayout(NUX_TRACKER_LOCATION);
     _tabview_scroll_button_layout->SetParentObject(this);
-    _scroll_right           = new InputArea(NUX_TRACKER_LOCATION);
-    _scroll_left           = new InputArea(NUX_TRACKER_LOCATION);
+    _scroll_right           = new BasicView(NUX_TRACKER_LOCATION);
+    _scroll_left           = new BasicView(NUX_TRACKER_LOCATION);
 
     _scroll_right->SetMinimumSize(TAB_BUTTON_WIDTH, TAB_BUTTON_HEIGHT);
     _scroll_left->SetMinimumSize(TAB_BUTTON_WIDTH, TAB_BUTTON_HEIGHT);
@@ -123,9 +123,9 @@ namespace nux
 
 
     tabright_callback = new TimerFunctor;
-    tabright_callback->time_expires.connect(sigc::mem_fun(this, &TabView::RecvTabRightTimerExpired));
+    tabright_callback->tick.connect(sigc::mem_fun(this, &TabView::RecvTabRightTimerExpired));
     tableft_callback = new TimerFunctor;
-    tableft_callback->time_expires.connect(sigc::mem_fun(this, &TabView::RecvTabLeftTimerExpired));
+    tableft_callback->tick.connect(sigc::mem_fun(this, &TabView::RecvTabLeftTimerExpired));
   }
 
   TabView::~TabView()
@@ -518,13 +518,13 @@ namespace nux
   void TabView::RecvTabRightTimerExpired(void *v)
   {
     TranslateTabLayout(-10);
-    m_TabRightTimerHandler = GetTimer().AddTimerHandler(10, tabright_callback, this);
+    m_TabRightTimerHandler = GetTimer().AddOneShotTimer(10, tabright_callback, this);
   }
 
   void TabView::RecvTabLeftTimerExpired(void *v)
   {
     TranslateTabLayout(10);
-    m_TabLeftTimerHandler = GetTimer().AddTimerHandler(10, tableft_callback, this);
+    m_TabLeftTimerHandler = GetTimer().AddOneShotTimer(10, tableft_callback, this);
   }
 
   bool TabView::AcceptKeyNavFocus()
