@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 Inalogic® Inc.
+ * Copyright 2010-2012 Inalogic® Inc.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License, as
@@ -32,6 +32,9 @@
 
 #include "Constants.h"
 
+#define DEGTORAD(d) (d) * nux::constants::pi / 180.0f
+#define RADTODEG(d) (d) * 180.0f / nux::constants::pi
+
 namespace nux
 {
   template<typename T> inline T Square (const T A)
@@ -55,7 +58,7 @@ namespace nux
 
   template<typename T> inline T Align (const T Ptr, int Alignment)
   {
-    return (T) (((NUX_POINTER) Ptr + Alignment - 1) & ~ (Alignment - 1));
+    return (T) (((unsigned int) Ptr + Alignment - 1) & ~ (Alignment - 1));
   }
 
   //Bitwise rotation on the left.
@@ -161,7 +164,7 @@ namespace nux
   */
   inline double RandomGaussian()
   {
-    return std::sqrt (-2 * std::log ((double) (1e-10 + (1 - 2e-10) * std::rand()))) * std::cos ((double) (2 * 3.14f/*Const::pi*/*std::rand()));
+    return std::sqrt (-2 * std::log ((double) (1e-10 + (1 - 2e-10) * std::rand()))) * std::cos ((double) (2 * constants::pi * std::rand()));
   }
 
   inline unsigned int RandomUInt()
@@ -174,20 +177,20 @@ namespace nux
     return std::rand() % max_random;
   }
 
-  inline t_size DiffPointer (void *Ptr0, void *Ptr1)
+  inline size_t DiffPointer (void *Ptr0, void *Ptr1)
   {
-    if ((t_size) Ptr0 >= (t_size) Ptr1) return (t_size) ((t_size) Ptr0 - (t_size) Ptr1);
+    if ((size_t) Ptr0 >= (size_t) Ptr1) return (size_t) ((size_t) Ptr0 - (size_t) Ptr1);
 
-    return (t_size) ((t_size) Ptr1 - (t_size) Ptr0);
+    return (size_t) ((size_t) Ptr1 - (size_t) Ptr0);
   }
   // Dangerous to use!
-  template<typename T> inline T SubstractPointer (void *Ptr, t_size Value)
+  template<typename T> inline T SubstractPointer (void *Ptr, size_t Value)
   {
-    return (T) (((t_size) Ptr) - Value);
+    return (T) (((size_t) Ptr) - Value);
   }
-  template<typename T> inline T AddPointer (void *Ptr, t_size Value)
+  template<typename T> inline T AddPointer (void *Ptr, size_t Value)
   {
-    return (T) (((t_size) Ptr) + Value);
+    return (T) (((size_t) Ptr) + Value);
   }
 
   //! Round up to the nearest multiple of Alignment that is greater or equal to Value
@@ -221,11 +224,11 @@ namespace nux
       Revert Byte order
       0x0011 -> 0x1100
   */
-  inline t_u16 ReverseByteOrdering (t_u16 value)
+  inline unsigned short ReverseByteOrdering (unsigned short value)
   {
-    t_u16 temp;
-    t_u8 *src = (t_u8 *) &value;
-    t_u8 *dest = (t_u8 *) &temp;
+    unsigned short temp;
+    unsigned char *src = (unsigned char *) &value;
+    unsigned char *dest = (unsigned char *) &temp;
 
     dest[0] = src[1];
     dest[1] = src[0];
@@ -237,11 +240,11 @@ namespace nux
       Revert Byte order
       0x00112233 -> 0x33221100
   */
-  inline t_u32 ReverseByteOrdering (t_u32 value)
+  inline unsigned int ReverseByteOrdering (unsigned int value)
   {
-    t_u32 temp;
-    t_u8 *src = (t_u8 *) &value;
-    t_u8 *dest = (t_u8 *) &temp;
+    unsigned int temp;
+    unsigned char *src = (unsigned char *) &value;
+    unsigned char *dest = (unsigned char *) &temp;
 
     dest[0] = src[3];
     dest[1] = src[2];
@@ -255,11 +258,11 @@ namespace nux
       Revert Byte order
       0x0011223344556677 -> 0x7766554433221100
   */
-  inline t_u64 ReverseByteOrdering (t_u64 value)
+  inline unsigned long long ReverseByteOrdering (unsigned long long value)
   {
-    t_u64 temp;
-    t_u8 *src = (t_u8 *) &value;
-    t_u8 *dest = (t_u8 *) &temp;
+    unsigned long long temp;
+    unsigned char *src = (unsigned char *) &value;
+    unsigned char *dest = (unsigned char *) &temp;
 
     dest[0] = src[7];
     dest[1] = src[6];
