@@ -48,6 +48,7 @@ namespace nux
     bool IsNull() const;
 
     bool IsInside(const Point &p) const;
+    bool IsInside(const Point2D<float> &p) const;
     Rect Intersect(const Rect &) const;
 
     // expand the width by factor_x and the height by factor_y
@@ -117,6 +118,11 @@ namespace nux
     int width, height;
   };
 
+  Rect operator+(Rect const& lhs, Rect const& rhs);
+  Rect operator-(Rect const& lhs, Rect const& rhs);
+  Rect operator*(Rect const& lhs, float scalar);
+
+
 }
 
 #endif // RECT_H
