@@ -49,12 +49,12 @@ namespace nux
       @param WindowHeight Window height.
       @param Style Window style.
       @param parent The parent window.
-      @param FullscreenFlag True to create a full screen window.
+      @param fullscreen_flag True to create a full screen window.
       @param create_rendering_data If true, then in GraphicsEngine, the system creates the OpenGL shaders and the font textures for the rendering.
     */
     GraphicsDisplay *CreateGLWindow(const char *WindowTitle, unsigned int WindowWidth, unsigned int WindowHeight, WindowStyle Style,
       GraphicsDisplay *parent,
-      bool FullscreenFlag = false,
+      bool fullscreen_flag = false,
       bool create_rendering_data = true);
 
 #if defined(NUX_OS_WINDOWS)
