@@ -22,6 +22,8 @@
 
 #include "Helpers.h"
 
+#include "NuxCore/LoggingWriter.h"
+
 #include <fstream>
 #include <stdexcept>
 
@@ -47,6 +49,21 @@ void PumpGObjectMainLoop()
   }
 }
 
+CaptureLogOutput::CaptureLogOutput()
+{
+  logging::Writer::Instance().SetOutputStream(sout_);
+}
+
+CaptureLogOutput::~CaptureLogOutput()
+{
+  logging::Writer::Instance().SetOutputStream(std::cout);
+}
+
+std::string CaptureLogOutput::GetOutput()
+{
+  return sout_.str();
+}
+
 
 }
 }
