@@ -313,6 +313,29 @@ void TestingThread(nux::NThread* thread, void* user_data)
     test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "TextEntry is empty");
   }
 
+  // Send invalid keys
+  {
+    test.ViewSendKeyCombo(XK_Control_L, 0, 0, 'r');
+    test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "Invalid key: TextEntry is empty");
+    nux::SleepForMilliseconds(500);
+
+    test.ViewSendKeyCombo(XK_Control_L, 0, 0, 'w');
+    test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "Invalid key: TextEntry is empty");
+    nux::SleepForMilliseconds(500);
+
+    test.ViewSendKeyCombo(XK_Control_L, 0, 0, 'g');
+    test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "Invalid key: TextEntry is empty");
+    nux::SleepForMilliseconds(500);
+
+    test.ViewSendKeyCombo(XK_Control_L, 0, 0, 'h');
+    test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "Invalid key: TextEntry is empty");
+    nux::SleepForMilliseconds(500);
+
+    nux::SleepForMilliseconds(500);
+    test.ViewSendCtrlA();
+    test.ViewSendDelete();
+  }
+
   // Toggle IBus
   // Type "qwerty"
   // Simulate key '1' to select the first IM option
@@ -330,13 +353,13 @@ void TestingThread(nux::NThread* thread, void* user_data)
     {
       // Type random stuff
       {
-        test.ViewSendString("qwerty");
+        test.ViewSendString("ninhao");
         nux::SleepForMilliseconds(500);
         test.TestReportMsg(test_textentry->text_entry_->GetText() == "", "TextEntry is only Preedit");
 
         test.ViewSendChar('1');
         nux::SleepForMilliseconds(500);
-        test.TestReportMsg(test_textentry->text_entry_->GetText() == "请问儿童有", "TextEntry is \"请问儿童有\"");
+        test.TestReportMsg(test_textentry->text_entry_->GetText() == "您好", "TextEntry is \"您好\"");
 
         test.ViewSendCtrlA();
         nux::SleepForMilliseconds(500);
